summaryrefslogtreecommitdiffstats
path: root/korganizer/kodaymatrix.h
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/kodaymatrix.h')
-rw-r--r--korganizer/kodaymatrix.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/korganizer/kodaymatrix.h b/korganizer/kodaymatrix.h
index 443ecc0e..37a48ebd 100644
--- a/korganizer/kodaymatrix.h
+++ b/korganizer/kodaymatrix.h
@@ -57,11 +57,11 @@ class DynamicTip : public TQToolTip
{
public:
/**
* Constructor that expects a KODayMatrix object as tqparent.
*
* @param tqparent the tqparent KODayMatrix control.
*/
- DynamicTip( TQWidget *tqparent );
+ DynamicTip( TQWidget *parent );
protected:
/**
@@ -73,7 +73,7 @@ class DynamicTip : public TQToolTip
void maybeTip( const TQPoint &pos );
private:
/** the tqparent control this tooltip is designed for. */
KODayMatrix *mMatrix;
};
@@ -109,11 +109,11 @@ class KODayMatrix: public TQFrame, public KCal::Calendar::Observer
public:
/** constructor to create a day matrix widget.
*
* @param tqparent widget that is the tqparent of the day matrix.
* Normally this should be a KDateNavigator
* @param name name of the widget
*/
- KODayMatrix( TQWidget *tqparent, const char *name );
+ KODayMatrix( TQWidget *parent, const char *name );
/** destructor that deallocates all dynamically allocated private members.
*/
@@ -57,11 +57,11 @@ class DynamicTip : public TQToolTip
public:
/**
- * Constructor that expects a KODayMatrix object as tqparent.
+ * Constructor that expects a KODayMatrix object as parent.
*
@@ -57,11 +57,11 @@ class DynamicTip : public TQToolTip
*
- * @param tqparent the tqparent KODayMatrix control.
+ * @param parent the parent KODayMatrix control.
*/
@@ -73,7 +73,7 @@ class DynamicTip : public TQToolTip
void maybeTip( const TQPoint &pos );
private:
- /** the tqparent control this tooltip is designed for. */
+ /** the parent control this tooltip is designed for. */
KODayMatrix *mMatrix;
};
@@ -109,11 +109,11 @@ class KODayMatrix: public TQFrame, public KCal::Calendar::Observer
/** constructor to create a day matrix widget.
*
- * @param tqparent widget that is the tqparent of the day matrix.
+ * @param parent widget that is the parent of the day matrix.
* Normally this should be a KDateNavigator
* @param name name of the widget